henet
    * ``auth_username`` Specify username for authentication

    * ``auth_password`` Specify password for authentication


.. note::
   
   A provider for Hurricane Electric DNS.
           NOTE: THIS DOES NOT WORK WITH 2-FACTOR AUTHENTICATION.
                 YOU MUST DISABLE IT IF YOU'D LIKE TO USE THIS PROVIDER.
           

